- x
Numeric (or string coercible to numeric). Vector of numbers that
might have lost trailing zeros.
- width
Integer. Number of decimal places the mantissas should have,
including the restored zeros. Default is NULL, in which case the number
of characters in the longest mantissa will be used instead.
- sep_in
Substring that separates the input's mantissa from its integer
part. Default is "\\.", which renders a decimal point.
- sep_out
Substring that will be returned in the output to separate the
mantissa from the integer part. By default, sep_out is the same as
sep_in.
- sep
[Deprecated] Use sep_in, not sep. If sep is specified
nonetheless, sep_in takes on sep's value.
- data
Data frame or matrix. Only in restore_zeros_df(), and instead
of x.
- cols
Only in restore_zeros_df(). Select columns from data using
tidyselect.
Default is everything(), which selects all columns that pass the test of
check_numeric_like.
- check_numeric_like
Logical. Only in restore_zeros_df(). If TRUE
(the default), the function will skip columns that are not numeric or
coercible to numeric, as determined by is_numeric_like().
- check_decimals
Logical. Only in restore_zeros_df(). If set to
TRUE, the function will skip columns where no values have any decimal
places. Default is FALSE.
- ...
Only in restore_zeros_df(). These dots must be empty.